Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(597)

Unified Diff: services/ui/surfaces/mojo_frame_sink_manager.h

Issue 2797453002: Rename DisplayCompositor to MojoFrameSinkManager. (Closed)
Patch Set: Fix comments. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/surfaces/mojo_frame_sink_manager.h
diff --git a/services/ui/surfaces/display_compositor.h b/services/ui/surfaces/mojo_frame_sink_manager.h
similarity index 82%
rename from services/ui/surfaces/display_compositor.h
rename to services/ui/surfaces/mojo_frame_sink_manager.h
index a14704d40094f9e40dcac41a1764243db8fca70d..134789c34c49df013f1aa6e0103be653b4def53f 100644
--- a/services/ui/surfaces/display_compositor.h
+++ b/services/ui/surfaces/mojo_frame_sink_manager.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef SERVICES_UI_SURFACES_DISPLAY_COMPOSITOR_H_
-#define SERVICES_UI_SURFACES_DISPLAY_COMPOSITOR_H_
+#ifndef SERVICES_UI_SURFACES_MOJO_FRAME_SINK_MANAGER_H_
+#define SERVICES_UI_SURFACES_MOJO_FRAME_SINK_MANAGER_H_
#include <stdint.h>
@@ -12,7 +12,7 @@
#include "base/macros.h"
#include "base/threading/thread_checker.h"
-#include "cc/ipc/display_compositor.mojom.h"
+#include "cc/ipc/frame_sink_manager.mojom.h"
#include "cc/surfaces/frame_sink_id.h"
#include "cc/surfaces/surface_manager.h"
#include "cc/surfaces/surface_observer.h"
@@ -24,24 +24,24 @@ namespace ui {
class DisplayProvider;
// The DisplayCompositor object is an object global to the Window Server app
// that holds the SurfaceServer and allocates new Surfaces namespaces.
// This object lives on the main thread of the Window Server.
// TODO(rjkroege, fsamuel): This object will need to change to support multiple
// displays.
-class DisplayCompositor
+class MojoFrameSinkManager
msw 2017/04/03 19:22:13 q: Why use Mojo in this name? Maybe explain in com
kylechar 2017/04/03 19:54:15 There is a cc::FrameSinkManager already :( MojoFra
danakj 2017/04/03 19:55:15 Also this is managing MojoCompositorFrameSink, so
msw 2017/04/03 20:07:34 Then I'd ask the same question of MojoCompositorFr
danakj 2017/04/03 20:11:15 We had that discussion on the CL that introduced t
: public cc::SurfaceObserver,
public display_compositor::GpuCompositorFrameSinkDelegate,
- public cc::mojom::DisplayCompositor {
+ public cc::mojom::FrameSinkManager {
public:
- DisplayCompositor(DisplayProvider* display_provider,
- cc::mojom::DisplayCompositorRequest request,
- cc::mojom::DisplayCompositorClientPtr client);
- ~DisplayCompositor() override;
+ MojoFrameSinkManager(DisplayProvider* display_provider,
+ cc::mojom::FrameSinkManagerRequest request,
+ cc::mojom::FrameSinkManagerClientPtr client);
+ ~MojoFrameSinkManager() override;
cc::SurfaceManager* manager() { return &manager_; }
- // cc::mojom::DisplayCompositor implementation:
+ // cc::mojom::MojoFrameSinkManager implementation:
void CreateRootCompositorFrameSink(
const cc::FrameSinkId& frame_sink_id,
gpu::SurfaceHandle surface_handle,
@@ -97,12 +97,12 @@ class DisplayCompositor
base::ThreadChecker thread_checker_;
- cc::mojom::DisplayCompositorClientPtr client_;
- mojo::Binding<cc::mojom::DisplayCompositor> binding_;
+ cc::mojom::FrameSinkManagerClientPtr client_;
+ mojo::Binding<cc::mojom::FrameSinkManager> binding_;
- DISALLOW_COPY_AND_ASSIGN(DisplayCompositor);
+ DISALLOW_COPY_AND_ASSIGN(MojoFrameSinkManager);
};
} // namespace ui
-#endif // SERVICES_UI_SURFACES_DISPLAY_COMPOSITOR_H_
+#endif // SERVICES_UI_SURFACES_MOJO_FRAME_SINK_MANAGER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -24,24 +24,24 @@ namespace ui {
class DisplayProvider;
-// The DisplayCompositor object is an object global to the Window Server app
+// The MojoFrameSinkManager object is an object global to the Window Server app
// that holds the SurfaceServer and allocates new Surfaces namespaces.
// This object lives on the main thread of the Window Server.